@@ -8,9 +8,9 @@ import pandas as pd
 import google.protobuf.wrappers_pb2 as proto
 from google.protobuf.json_format import MessageToJson
 import numpy as np
-import google
 import math
 
+
 def __isTimeDataType(dataType):
     return dataType in frozenset(['TimeColumnConfig', 'StaticTimeConfig'])
 
@@ -51,15 +51,19 @@ def __getDataLoadMappings(columnConfigs, valueModifiers):
         timeTuples=timeTuples
     )
 
+
 def __isStringColumnType(columnType):
     return columnType == api.ColumnType.Value("String")
 
+
 def __isTimeColumnType(columnType):
     return columnType == api.ColumnType.Value("Time")
 
+
 def __isNumberColumnType(columnType):
     return columnType == api.ColumnType.Value("Number")
 
+
 def __columnTypeToString(projectedColumn):
     if __isStringColumnType(projectedColumn.type):
         return "String"
@@ -69,8 +73,6 @@ def __columnTypeToString(projectedColumn):
         return "Number"
 
 
-
-
 #######################################
 ### Pandas helpers to read meta
 ############
@@ -95,6 +97,7 @@ def __getSampleRowsPandas(df):
     return rowSamples
 
 
+# Immutable on df
 def __getColumnSamplesPandas(df):
     columnSamples = []
     for col in df.columns:
@@ -107,6 +110,7 @@ def __getColumnSamplesPandas(df):
     return columnSamples
 
 
+# Immutable on df
 def __getColumnConfigsPandas(df: pd.DataFrame):
     typedColumnConfigs = []
     pythonConfigs = []
@@ -146,7 +150,8 @@ def __makeLineQueryPandas(line_query):
     # Make the filter expression from columns
     for filt in line_query.filters:
         if len(filt.stringFilter.stringFilter) > 0:
-            filt_str = ' or '.join(f'{filt.stringFilter.name} == "{filtValue.value.value}"' for filtValue in filt.stringFilter.stringFilter)
+            filt_str = ' or '.join(f'{filt.stringFilter.name} == "{filtValue.value.value}"' for filtValue in
+                                   filt.stringFilter.stringFilter)
             filterExprs.append(f'({filt_str})')
         elif len(filt.numberFilter.numberFilter):
             if len(filt.numberFilter.numberFilter) == 1:
@@ -155,12 +160,13 @@ def __makeLineQueryPandas(line_query):
             else:
                 filt_num = f'{filt.numberFilter.name} >= {filt.numberFilter.numberFilter[0]} and {filt.numberFilter.name} < {filt.numberFilter.numberFilter[1]}'
                 filterExprs.append(f'({filt_num})')
-        #TODO: Support time filter after server format is known
+        # TODO: Support time filter after server format is known
         elif type == "Time":
             pass
     return filterExprs
 
 
+# Immutable on df
 def getDatasourceMetaReplyPandas(df, ds_id, ds_name):
     typedColumnConfigsAndMeta = __getColumnConfigsPandas(df)
     valueModifiers = []
@@ -186,13 +192,16 @@ def __dataTypeToString(dataType):
         return "String"
     raise Exception(f'Unsupprted dataType: {dataType}')
 
-def __tsToUnixEpochSeconds(timeStamp):
-    return np.int_(timeStamp.value / 10**9)
 
+def __tsToUnixEpochSeconds(timeStamp):
+    return np.int_(timeStamp.value / 10 ** 9)
+
+
+# Immutable on df
 # project_cols is a ProjectColumn[] grpc message
 # Iterate a dataframe's rows as api.DataRecordsReply
 # time columns must be serialized as numbers prior to this
-def __serializeDataFrame(df, project_cols, chunk_size = 100):
+def __serializeDataFrame(df, project_cols, chunk_size=100):
     string_project = list(filter(lambda x: __isStringColumnType(x.type), project_cols))
     string_names = list(map(lambda x: x.name, string_project))
     string_dict = dict([(item, index) for (index, item) in enumerate(string_names)])
@@ -219,28 +228,32 @@ def __serializeDataFrame(df, project_cols, chunk_size = 100):
                     if row[col.name] == None:
                         strings[string_dict[col.name]] = api.OptionalString(value=None)
                     else:
-                        strings[string_dict[col.name]] = api.OptionalString(value=proto.StringValue(value=row[col.name]))
+                        strings[string_dict[col.name]] = api.OptionalString(
+                            value=proto.StringValue(value=row[col.name]))
 
                 # Numbers
                 elif __isNumberColumnType(col.type):
                     if row[col.name] == None or math.isnan(row[col.name]):
                         numbers[number_dict[col.name]] = api.OptionalNumber(value=None)
                     else:
-                        numbers[number_dict[col.name]] = api.OptionalNumber(value=proto.DoubleValue(value=row[col.name]))
+                        numbers[number_dict[col.name]] = api.OptionalNumber(
+                            value=proto.DoubleValue(value=row[col.name]))
 
                 # Times
                 elif __isTimeColumnType(col.type):
                     if row[col.name] == None or math.isnan(row[col.name].value):
                         times[time_dict[col.name]] = api.OptionalTime(value=None)
                     else:
-                        times[time_dict[col.name]] = api.OptionalTime(value=proto.Int64Value(value=__tsToUnixEpochSeconds(row[col.name])))
+                        times[time_dict[col.name]] = api.OptionalTime(
+                            value=proto.Int64Value(value=__tsToUnixEpochSeconds(row[col.name])))
             data_records.append(api.DataRecord(strings=strings, numbers=numbers, times=times))
         yield api.DataRecordsReply(records=data_records)
 
 
-def dataSourceUniquesStreamPandas(df, request, chunk_size = 100):
+# Immutable on df
+def dataSourceUniquesStreamPandas(df, request, chunk_size=100):
     print("dataSourceUniquesStreamPandas", MessageToJson(request))
-    df_names = list(map(lambda c:  c.name, request.projectColumns))
+    df_names = list(map(lambda c: c.name, request.projectColumns))
     stringsOnly = list(
         df[df_names].select_dtypes(include=['category', 'object']).columns
     )
@@ -249,18 +262,19 @@ def dataSourceUniquesStreamPandas(df, request, chunk_size = 100):
     yield from __serializeDataFrame(unique_df, request.projectColumns, chunk_size)
 
 
+# !! Mutates DF (sorts on time on query result)
 def dataSourceQueryStreamPandas(df, request):
     print("dataSourceQueryStreamPandas", MessageToJson(request))
 
     # Grab the projections we care about
-    project_names = list(map(lambda x: x.name, request.projectCols))
+    project_names = list(map(lambda x: x.name, request.projectColumns))
 
     # Grab our string + time projections to sort byt
-    string_project = list(filter(lambda x: __isStringColumnType(x.type), request.projectCols))
-    string_names = list(filter(lambda x: x.name), string_project))
+    string_project = list(filter(lambda x: __isStringColumnType(x.type), request.projectColumns))
+    string_names = list(map(lambda x: x.name, filter(lambda x: x.name, string_project)))
 
-    time_project = list(filter(lambda x: __isTimeColumnType(x.type), request.projectCols))
-    time_names = list(filter(lambda x: x.name), time_project))
+    time_project = list(filter(lambda x: __isTimeColumnType(x.type), request.projectColumns))
+    time_names = list(map(lambda x: x.name, filter(lambda x: x.name, time_project)))
 
     for line_query in request.lineQueries:
         # Apply the line query to filter to
@@ -269,6 +283,7 @@ def dataSourceQueryStreamPandas(df, request):
 
         # Filter data + sort by time
         line_result_df = df[project_names].query(line_query)
+        # !! Mutates !!
         line_result_df.sort_values(by=string_names + time_names, inplace=True)
 
         # Send our batch -- do it in 1 chunk
